Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Handler ¶
type Handler interface {
// GetFaultLogPageList get the fault site paging log
// @Tags API.log
// @Router /api/log/fault/pagelist [post]
GetFaultLogPageList() core.HandlerFunc
// GetFaultLogContent get the contents of the fault site log
// @Tags API.log
// @Router /api/log/fault/content [post]
GetFaultLogContent() core.HandlerFunc
// QueryLog query full logs
// @Tags API.log
// @Router /api/log/query [post]
QueryLog() core.HandlerFunc
// GetLogChart get the log trend chart
// @Tags API.log
// @Router /api/log/chart [post]
GetLogChart() core.HandlerFunc
// GetLogIndex analysis field index
// @Tags API.log
// @Router /api/log/index [post]
GetLogIndex() core.HandlerFunc
// GetLogTableInfo get log table information
// @Tags API.log
// @Router /api/log/table get
GetLogTableInfo() core.HandlerFunc
// GetServiceRoute get the application log corresponding to the service
// @Tags API.log
// @Router /api/log/rule/service get
GetServiceRoute() core.HandlerFunc
// GetLogParseRule get log table parsing rules
// @Tags API.log
// @Router /api/log/rule/get [get]
GetLogParseRule() core.HandlerFunc
// UpdateLogParseRule update log table parsing rules
// @Tags API.log
// @Router /api/log/rule/update [post]
UpdateLogParseRule() core.HandlerFunc
// AddLogParseRule new log table parsing rules
// @Tags API.log
// @Router /api/log/rule/add [post]
AddLogParseRule() core.HandlerFunc
// DeleteLogParseRule delete log table parsing rules
// @Tags API.log
// @Router /api/log/rule/delete [delete]
DeleteLogParseRule() core.HandlerFunc
// OtherTable get the external log table
// @Tags API.log
// @Router /api/log/other get
OtherTable() core.HandlerFunc
// OtherTableInfo get external log table information
// @Tags API.log
// @Router /api/log/other/table [get]
OtherTableInfo() core.HandlerFunc
// AddOtherTable add external log table
// @Tags API.log
// @Router /api/log/other/add [post]
AddOtherTable() core.HandlerFunc
// DeleteOtherTable remove external log table
// @Tags API.log
// @Router /api/log/other/delete [delete]
DeleteOtherTable() core.HandlerFunc
// QueryLogContext get the log context
// @Tags API.log
// @Router /api/log/context [post]
QueryLogContext() core.HandlerFunc
}
func New ¶
func New(logger *zap.Logger, chRepo clickhouse.Repo, dbRepo database.Repo, k8sApi kubernetes.Repo, promRepo prometheus.Repo) Handler
Source Files
¶
- func_addothertable.go
- func_addparserule.go
- func_deleteothertable.go
- func_deleteparserule.go
- func_getfaultlogcontent.go
- func_getfaultloglist.go
- func_getlogchart.go
- func_getlogindex.go
- func_getlogparserule.go
- func_getlogtableinfo.go
- func_getserviceroute.go
- func_othertable.go
- func_othertableinfo.go
- func_querylog.go
- func_querylogcontext.go
- func_updatelogparserule.go
- handler.go
Click to show internal directories.
Click to hide internal directories.