team

package
v0.0.0-...-f8547f2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Handler

type Handler interface {
	// CreateTeam Creates a team.
	// @Tags API.team
	// @Router /api/team/create [post]
	CreateTeam() core.HandlerFunc

	// UpdateTeam Update team's information.
	// @Tags API.team
	// @Router /api/team/update [post]
	UpdateTeam() core.HandlerFunc

	// GetTeam Get teams.
	// @Tags API.team
	// @Router /api/team [get]
	GetTeam() core.HandlerFunc

	// DeleteTeam Delete a team.
	// @Tags API.team
	// @Router /api/team/delete [post]
	DeleteTeam() core.HandlerFunc

	// TeamOperation Assigns a user to teams or removes a user from teams.
	// @Tags API.team
	// @Router /api/team/operation [post]
	TeamOperation() core.HandlerFunc

	// TeamUserOperation Assigns users to a team or remove user from a team.
	// @Tags API.team
	// @Router /api/team/user/operation [post]
	TeamUserOperation() core.HandlerFunc

	// GetTeamUser Get team's users.
	// @Tags API.team
	// @Router /api/team/user [get]
	GetTeamUser() core.HandlerFunc
}

func New

func New(logger *zap.Logger, dbRepo database.Repo) Handler

Jump to